@@ -453,6 +453,17 @@ msgstr ""
 ''')
         self.assertEqual(pofile.__unicode__(), expected)
 
+    def test_trailing_comment(self):
+        pofile  = polib.pofile('tests/test_trailing_comment.po')
+        expected = r'''# 
+msgid ""
+msgstr "Content-Type: text/plain; charset=UTF-8\n"
+
+msgid "foo"
+msgstr "oof"
+'''
+        self.assertEqual(str(pofile), expected)
+
 class TestPoFile(unittest.TestCase):
     """
     Tests for PoFile class.
@@ -530,6 +541,11 @@ class TestPoFile(unittest.TestCase):
         e = po.find("Some comment starting with two '#'", by='tcomment')
         self.assertTrue(isinstance(e, polib.POEntry))
 
+    def test_word_garbage(self):
+        po = polib.pofile('tests/test_word_garbage.po')
+        e = po.find("Whatever", by='msgid')
+        self.assertTrue(isinstance(e, polib.POEntry))
+
 class TestMoFile(unittest.TestCase):
     """
     Tests for MoFile class.
@@ -585,6 +601,22 @@ msgid "singular"
 msgid_plural "plural"
 msgstr[0] "singulier"
 msgstr[1] "pluriel"
+''')
+        self.assertEqual(mo.__unicode__(), expected)
+
+    def test_invalid_version(self):
+        self.assertRaises(IOError, polib.mofile, 'tests/test_invalid_version.mo')
+
+    def test_no_header(self):
+        mo = polib.mofile('tests/test_no_header.mo')
+        expected = u('''msgid ""
+msgstr ""
+
+msgid "bar"
+msgstr "rab"
+
+msgid "foo"
+msgstr "oof"
 ''')
         self.assertEqual(mo.__unicode__(), expected)
 
